# Module globals
# NONE

# User interface
dataSummaryUI <- function(id)
{
  ns <- NS(id)

  tagList(
    div(style = "margin-top: 15px"),
    box(
      width = 12,
      title = "Input data summary",
      solidHeader = FALSE,
      status = "primary",
      collapsible = TRUE,
      withSpinner(
        tagList(
          h3("1. Missing data summary"),
          plotOutput(ns("missPlot")),
          h3("2. Observed delay density"),
          uiOutput(ns("delayDensityOutput")),
          h3("3. Observed delay by notification time"),
          uiOutput(ns("meanDelayOutput"))
        ),
        type = 7,
        proxy.height = "50px")
    ),
    box(
      width = 12,
      title = "Input data records pre-processed",
      solidHeader = FALSE,
      status = "warning",
      collapsible = TRUE,
      dataTableOutput(ns("inputDataTable"))
    )
  )
}

# Server logic
dataSummary <- function(input, output, session, inputData)
{
  # Get namespace
  ns <- session$ns

  artifacts <- reactive({
    GetDataSummaryArtifacts(inputData())
  })

  output[["missPlot"]] <- renderPlot({
    replayPlot(artifacts()$MissPlot)
  })

  output[["delayDensityOutput"]] <- renderUI({
    delayDensFullPlot <- artifacts()$DelayDensFullPlot
    delayDensShortPlot <- artifacts()$DelayDensFullPlot
    if (!is.null(delayDensShortPlot) & !is.null(delayDensShortPlot)) {
      plotOutput(ns("delayDensityPlot"))
    } else {
      p("This plot cannot be created due to missingness in the provided diagnosis and notification times.")
    }
  })

  output[["delayDensityPlot"]] <- renderPlot({
    delayDensFullPlot <- artifacts()$DelayDensFullPlot
    delayDensShortPlot <- artifacts()$DelayDensShortPlot
    PlotMultipleCharts(list(delayDensFullPlot,
                            delayDensShortPlot),
                       cols = 2)
  })

  output[["meanDelayOutput"]] <- renderUI({
    meanDelayPlot <- artifacts()$MeanDelayPlot
    if (!is.null(meanDelayPlot)) {
      plotOutput(ns("meanDelayPlot"))
    } else {
      p("This plot cannot be created due to missingness in the provided diagnosis and notification times.")
    }
  })

  output[["meanDelayPlot"]] <- renderPlot({
    artifacts()$MeanDelayPlot
  })


  output[["inputDataTable"]] <- renderDataTable(inputData(),
                                                options = list(
                                                  autoWidth = FALSE,
                                                  pageLength = 10,
                                                  scrollX = TRUE,
                                                  deferRender = TRUE,
                                                  serverSide = TRUE,
                                                  scroller = FALSE))
}
